/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 997 $
 * $Date: 2020-03-19 13:49:34 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.general.dtypes;

import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamReader;
import javax.xml.stream.XMLStreamWriter;

import at.lcm.bu21.general.utils.Clone;
import at.lcm.bu21.general.utils.CloneException;

/**
 * Representation of a null-type
 * 
 * @author Werner Koppelsttter
 */
public class TNull extends TData {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/**
	 * Create empty object
	 */
	public TNull() {
	}

	@Override
	public TNull deepClone() throws CloneException {
		return (TNull) Clone.deepClone(this);
	}

	@Override
	public void xml2data(XMLStreamReader xmlReader) throws XMLStreamException {
		xmlReader.next();
		xmlReader.next();
	}

	@Override
	public void data2xml(XMLStreamWriter xmlWriter) throws XMLStreamException {
		xmlWriter.writeStartElement("Null");
		xmlWriter.writeEndElement();
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (this.getClass() != obj.getClass()) {
			return false;
		}
		return true;
	}

	@Override
	public String toString() {
		return "[]";
	}

}
