/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 1002 $
 * $Date: 2020-04-10 23:31:24 +0200 (Fri, 10 Apr 2020) $
 */
package at.lcm.bu21.general.dtypes.editor2;

import java.util.EventObject;

/**
 * Edit Child Event of a TArray or TStruct
 * 
 * @author Johannes Kaisinger
 */
public class EditChildEvent extends EventObject {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** key for TStruct */
	private String childKey;
	/** Row for TArray and TPeriodicMatrix */
	private int row;
	/** Column for TArray and TPeriodicMatrix */
	private int column;

	/**
	 * Create object with given size
	 * 
	 * @param source
	 *            Source of event
	 * @param row
	 *            Index of row (TArray)
	 * @param column
	 *            Index of row (TArray)
	 * @param childKey
	 *            String of childKey (TStruct)
	 * 
	 */
	public EditChildEvent(Object source, int row, int column, String childKey) {
		super(source);

		this.childKey = childKey;
		this.row = row;
		this.column = column;
	}

	/**
	 * Get the childKey which should be edited
	 * 
	 * @return ChildKey
	 *
	 */
	public String getChildKey() {
		return this.childKey;
	}

	/**
	 * Get the childRow which should be edited
	 * 
	 * @return row
	 *
	 */
	public int getRow() {
		return this.row;
	}

	/**
	 * Get the childColumn which should be edited
	 * 
	 * @return column
	 *
	 */
	public int getColumn() {
		return this.column;
	}
}
