/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 1002 $
 * $Date: 2020-04-10 23:31:24 +0200 (Fri, 10 Apr 2020) $
 */
package at.lcm.bu21.general.dtypes.editor2;

import javax.swing.table.AbstractTableModel;

import at.lcm.bu21.general.dtypes.editor2.TDataModel.TPeriodicSignalBuilderModel;
import at.lcm.bu21.general.dtypes.editor2.TDataModel.TPeriodicSignalBuilderModel.Signal;

/**
 * * This is a table model for a JTable to view TPeriodicSignals. It based on
 * AbstractTableModel.
 * 
 * @author jkaisinger
 *
 */
public class TPeriodicSignalBuilderTableModel extends AbstractTableModel {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/**
	 * Local reference of the tPeriodicSignalBuilderModel. It allows to
	 * manipulate the TPeriodicSignal.
	 */
	private TPeriodicSignalBuilderModel tPeriodicSignalBuilderModel;

	/** Column header names. */
	private String[] colNames = { "Signal", "Offset", "Amplitude", "Phase", "Order", "Ratio" };

	/**
	 * Creates a object.
	 * 
	 * @param tPeriodicSignalBuilderModel
	 *            TPeriodicSignalBuilderModel
	 */
	public TPeriodicSignalBuilderTableModel(TPeriodicSignalBuilderModel tPeriodicSignalBuilderModel) {
		this.tPeriodicSignalBuilderModel = tPeriodicSignalBuilderModel;
	}

	/**
	 * Get Column name
	 * 
	 * @param column
	 *            Index of column.
	 */
	@Override
	public String getColumnName(int column) {
		return this.colNames[column];
	}

	@Override
	public int getRowCount() {
		return this.tPeriodicSignalBuilderModel.getLength();
	}

	@Override
	public int getColumnCount() {
		return this.colNames.length;
	}

	@Override
	public Class<?> getColumnClass(int column) {
		Class<?> res = null;

		if (column == 0) {
			res = Signal.class;
		} else if (column == 4) {
			res = Integer.class;
		} else {
			res = Double.class;
		}

		return res;
	}

	/**
	 * Get if a cell is editable.
	 * 
	 * @param row
	 *            Index of row.
	 * @param column
	 *            Index of column.
	 * @return isEditable
	 */
	@Override
	public boolean isCellEditable(int row, int column) {
		boolean res = true;

		Signal sig = this.tPeriodicSignalBuilderModel.getSignal(row);

		if ((sig == Signal.SIN) && (column == 5)) {
			res = false;
		}

		return res;
	}

	@Override
	public Object getValueAt(int row, int column) {
		Object val = null;

		Signal sig = this.tPeriodicSignalBuilderModel.getSignal(row);

		if (column == 0) {
			val = sig;
		} else if (column == 1) {
			val = this.tPeriodicSignalBuilderModel.getOffs(row);
		} else if (column == 2) {
			val = this.tPeriodicSignalBuilderModel.getAmpl(row);
		} else if (column == 3) {
			val = (this.tPeriodicSignalBuilderModel.getPhas(row) * 180.0) / Math.PI;
		} else if (column == 4) {
			val = this.tPeriodicSignalBuilderModel.getOrder(row);
		} else if (column == 5) {
			if (sig != Signal.SIN) {
				val = (this.tPeriodicSignalBuilderModel.getPhi(row) * 180.0) / Math.PI;
			}
		}

		return val;
	}

	@Override
	public void setValueAt(Object value, int row, int column) {

		if (column == 0) {
			Signal sig = (Signal) value;
			this.tPeriodicSignalBuilderModel.setSignal(row, sig);
		} else if (column == 1) {
			double offs = Double.parseDouble(value.toString());
			this.tPeriodicSignalBuilderModel.setOffs(row, offs);
		} else if (column == 2) {
			double ampl = Double.parseDouble(value.toString());
			this.tPeriodicSignalBuilderModel.setAmpl(row, ampl);
		} else if (column == 3) {
			double phas = (Double.parseDouble(value.toString()) * Math.PI) / 180.0;
			this.tPeriodicSignalBuilderModel.setPhas(row, phas);
		} else if (column == 4) {
			int order = Integer.parseInt(value.toString());
			this.tPeriodicSignalBuilderModel.setOrder(row, order);
		} else if (column == 5) {
			double phi = (Double.parseDouble(value.toString()) * Math.PI) / 180.0;
			this.tPeriodicSignalBuilderModel.setPhi(row, phi);
		}
		this.fireTableDataChanged();

	}

}
