/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 997 $
 * $Date: 2020-03-19 13:49:34 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.general.utils;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;

/**
 * Class to clone existing objects. All source object have to implement the
 * Serializable interface.
 * 
 * @author Werner Koppelsttter
 */
public class Clone {

	/**
	 * Create a deep clone of given object
	 * 
	 * @param obj
	 *            Object to clone
	 * @return Deep clone of object
	 * @throws CloneException
	 *             Unable to clone (serialize)
	 */
	public static Object deepClone(Serializable obj) throws CloneException {
		ByteArrayOutputStream baos;
		ObjectOutputStream oos;
		ByteArrayInputStream bais;
		ObjectInputStream ois;
		Object result = null;

		try {
			baos = new ByteArrayOutputStream();
			oos = new ObjectOutputStream(baos);
			oos.writeObject(obj);
			bais = new ByteArrayInputStream(baos.toByteArray());
			ois = new ObjectInputStream(bais);
			result = ois.readObject();
		} catch (IOException e) {
			throw new CloneException("Unable to clone object", e);
		} catch (ClassNotFoundException e) {
			throw new CloneException("Unable to clone object", e);
		}

		return result;
	}

}
