from dtypes.tnull import TNull

from lxml import etree
import dtypes.xml
from dtypes import TData
import numpy as np

class TArray(np.ndarray, TData):
    
    _tag="Array"
    
    def __new__(cls, nrows, ncols):
        shape=[nrows, ncols]
        obj=np.full(shape, TNull(), dtype=TData)
        return obj.view(cls)
        
    def __setitem__(self, tup, val):
        if len(tup) != 2:
            raise Exception("index requires 2 dimensions!")
        val=dtypes.xml.toTData(val)
        super(TArray, self).__setitem__(tup, val)
        
    def __getitem__(self, tup):
        if len(tup) != 2:
            raise Exception("index requires 2 dimensions!")
        return super(TArray, self).__getitem__(tup)
        
    
    def __str__(self):
        return self.__repr__()
            
    def __repr__(self):
        return "[%dx%d %s]" % (self.shape[0], self.shape[1], self._tag)
               
        
    @classmethod        
    def fromXML(cls, node):
        
        nrows=len(node)
        ncols=len(node[0])
        
        obj=cls(nrows, ncols)
        
        for r, rowElem in enumerate(node):
            for c, elem in enumerate(rowElem):
                obj[r, c]=dtypes.xml.fromnode(elem)           
        return obj
    
    
    def data2xml(self):
        
        nrows=self.shape[0]
        ncols=self.shape[1]
        node=etree.Element(self._tag)
        node.attrib["nrows"] = str(nrows)
        node.attrib["ncolumns"] = str(ncols)
        
        for r in range(0, nrows):
            rowElem=etree.Element("row")            
            for c in range(0, ncols):
                tmp=self[r,c].data2xml()
                rowElem.append(tmp)                            
            node.append(rowElem)
        return node
