#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.5

$LastChangedRevision: 957 $
$LastChangedDate:: 2019-06-13 13:25:47 +0200#$

This file is part of SyMSpace.

Copyright (c) 2017, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""

import os
import sys
from abc import ABCMeta
from abc import abstractmethod


class PyJavaDataInterface(metaclass=ABCMeta):
    """Abstract class for interface for python (via jep) <-> java

    Java            | Python
    -------------------------
    ...             | ...
    ...             | ...
    ...             | ...

    """

    @staticmethod
    @abstractmethod
    def convert_J2Py(jobj):
        """
        Create a Python object equivalent to given Java object
        """
        raise NotImplementedError

    @staticmethod
    @abstractmethod
    def convert_Py2J(pyobj):
        """
        Create a Java object equivalent to the given python object
        """
        raise NotImplementedError

    @staticmethod
    def getInterpreter():
        interpPath = os.path.normpath(sys.executable)
        return os.path.splitext(os.path.basename(interpPath))[0]
