#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.5

$LastChangedRevision: 834 $
$LastChangedDate:: 2017-09-29 12:27:10 +0200#$

This file is part of SyMSpace.

Copyright (c) 2017, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""


def saveText2File(text_string, filepath, encoding='utf-8'):
    """
    Save a text string to a file

    Parameters
    ----------
    text_string : string
        text to write
    filepath : string
        path to the file e.g. C:\\tmp\\file.txt
    encoding : string
        encoding utf-8 (Default)

    """
    with open(filepath, 'w', encoding=encoding) as f:
        print(text_string, file=f)


def insertLineInFile(filepath, search_line, insert_line, skip_lines=1):
    """Function to open a text-file and replace (skip_lines=0) or insert a text-line,
        relative to a searched text-line

    Parameters
    ----------
    filepath : string
        path to the file e.g. C:\\tmp\\file.txt
    search_line : string
        content line to search for
    insert_line : string
        content line to insert
    skip_lines : integer
        number of lines past the search_line, where the insert_line is inserted
        if skip_lines = 0 the search_line will be replaced by the insert_line
        if skip_lines = 1 the insert_line will be inserted in the next line after the search_line (Default)

    """

    with open(filepath, 'r') as file:
        ''' read a list of lines into data'''
        data = file.readlines()
    line_index = data.index(search_line)
    if skip_lines == 0:
        '''replace line'''
        data[line_index] = insert_line
    else:
        if skip_lines < 0:
            skip_lines += 1
        data.insert(line_index + skip_lines, insert_line)
    with open(filepath, 'w', encoding='utf-8') as file:
        file.writelines(data)
