#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 1005 $
$LastChangedDate:: 2020-04-14 12:21:57 +0200#$

This file is part of SyMSpace.

Copyright (c) 2019, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
import numpy as np
import scipy.interpolate
import matplotlib.pyplot as plt
from lcm.math.rbf import rbf, transformations

x = np.linspace(0, 10, num=11, endpoint=True)
y = np.cos(-x ** 2 / 9.0)
x_new = np.linspace(0, 10, num=41, endpoint=True)
y_true = np.cos(-x_new ** 2 / 9.0)


def scipylinear():
    f = scipy.interpolate.interp1d(x, y, kind='linear')
    return f(x_new)


def scipycubic():
    f = scipy.interpolate.interp1d(x, y, kind='cubic')
    return f(x_new)


def scipyrbf():
    f = scipy.interpolate.rbf.Rbf(x, y)
    return f(x_new)


def numpyitp():
    return np.interp(x_new, x, y)


def scipyitp():
    return scipy.interp(x_new, x, y)


def scipyspline():
    f = scipy.interpolate.InterpolatedUnivariateSpline(x, y)
    return f(x_new)


def polyfit():
    z = np.polyfit(x, y, 15)
    p = np.poly1d(z)
    return p(x_new)


def symRBF():
    xc = np.zeros((1, x.size))
    xc[0, :] = x
    yc = np.zeros((1, x.size))
    yc[0, :] = y
    x_ = np.zeros((1, x_new.size))
    x_[0, :] = x_new

    t = transformations.normalization(xc)
    # f = rbf.RBF(xc, yc, t=t, gamma=1e-3, max_dist=0.5)
    f = rbf.RBF(xc, yc, t=t)
    return f(x_).flatten()


def plotAll():
    plt.figure()
    plt.plot(y_true, linewidth=3,  label='True')
    plt.plot(scipylinear(), '-.',  label='scipylinear')
    plt.plot(scipycubic(), '-.', label='scipycubic')
    plt.plot(scipyrbf(), '-.', label='scipyrbf')
    plt.plot(scipyitp(), '-.', label='scipyitp')
    plt.plot(numpyitp(), '-.', label='numpyitp')
    # plt.plot(polyfit(), '-.', label='polyfit')
    plt.plot(scipyspline(), '-.', label='scipyspline')
    plt.plot(symRBF(), '--', linewidth=3, label='symRBF')
    plt.legend()
    plt.grid()
    plt.show()


if __name__ == '__main__':
    import timeit
    number = 100
    d = dict()
    d['scipylinear'] = timeit.timeit("scipylinear()", setup="from __main__ import scipylinear", number=number)
    d['scipycubic'] = timeit.timeit("scipycubic()", setup="from __main__ import scipycubic", number=number)
    d['scipyrbf'] = timeit.timeit("scipyrbf()", setup="from __main__ import scipyrbf", number=number)
    d['numpyitp'] = timeit.timeit("numpyitp()", setup="from __main__ import numpyitp", number=number)
    d['scipyitp'] = timeit.timeit("scipyitp()", setup="from __main__ import scipyitp", number=number)
    d['scipyspline'] = timeit.timeit("scipyspline()", setup="from __main__ import scipyspline", number=number)
    # d['polyfit'] = timeit.timeit("polyfit()", setup="from __main__ import polyfit", number=number)
    d['symRBF'] = timeit.timeit("symRBF()", setup="from __main__ import symRBF", number=number)
    print(d)
    plt.figure()
    plt.bar(range(len(d)), list(d.values()), align='center')
    plt.xticks(range(len(d)), list(d.keys()))
    plt.grid()
    plotAll()
