# !/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 989 $
$LastChangedDate:: 2020-02-21 11:04:19 +0100#$

This file is part of SyMSpace.

Copyright (c) 2018, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""

import unittest
import numpy as np
from lcm.tdata_interface.pyjlist_interface import PyJListInterface


class TestPyJListInterface(unittest.TestCase):

    @classmethod
    @unittest.skipIf(PyJListInterface.getInterpreter() == 'python', 'needs jep interpreter to run')
    def setUpClass(cls):
        """

        Returns
        -------

        """
        # noinspection PyUnresolvedReferences
        from java.util import ArrayList

        '''list with same dimension entries '''
        '''1D'''
        array_r1 = [1, 2, 3.0]
        array_r2 = [1, 2, 'text']
        '''2D'''
        array_r3 = [[1], [2], [3]]
        array_r4 = [[1, 'text'], [2, 1], [3, 'text']]
        '''3D'''
        array_r5 = [[[1, 1]], [[2, 2]], [[3, 3]]]

        '''list with unequal dimension entries '''
        '''1D and 2D'''
        array_i1 = [[1, 'text'], [2], [3]]
        array_i2 = [[1], [2], [3, 'text']]
        array_i3 = [[1, ['text']], [2, [2]], [3]]

        ''' [input, expected output]'''
        cls.test_data_Py2J = []
        ''' [input, expected output]'''
        cls.test_data_J2Py = [(ArrayList(array_r1), np.array(array_r1, dtype=object)),
                              (ArrayList(array_r2), np.array(array_r2, dtype=object)),
                              (ArrayList(array_r3), np.array(array_r3, dtype=object)),
                              (ArrayList(array_r4), np.array(array_r4, dtype=object)),
                              (ArrayList(array_r5), np.array(array_r5, dtype=object)),
                              # (ArrayList(array_i1), np.array(array_i1, dtype=object)),
                              # (ArrayList(array_i2), np.array(array_i2, dtype=object)),
                              ]

    @unittest.skipIf(PyJListInterface.getInterpreter() == 'python', 'needs jep interpreter to run')
    def test_convert_J2Py(self):
        for index, data in enumerate(self.test_data_J2Py):
            jobj = data[0]
            pyobj_ref = data[1]
            with self.subTest(msg=str(index)):
                pyobj = PyJListInterface.convert_J2Py(jobj)
                np.testing.assert_equal(pyobj, pyobj_ref)

    @unittest.skipIf(PyJListInterface.getInterpreter() == 'python', 'needs jep interpreter to run')
    def test_convert_Py2J(self):
        pass


if __name__ == '__main__':
    from lcm.utils.testing import runUnittest

    runUnittest(PyJListInterface.getInterpreter())
