/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure;

import java.io.File;
import java.io.Serializable;
import java.rmi.Remote;
import java.rmi.RemoteException;

/**
 * Interface of component
 * 
 * @author Werner Koppelsttter
 */
public interface IComponent extends Remote, Serializable, Cloneable {

	/**
	 * Update project-path. Copy linked files and help-files if path is changed.
	 * 
	 * @throws RemoteException
	 */
	public void refresh() throws RemoteException;

	/**
	 * Get folder of component-files
	 * 
	 * @return Folder of component
	 * @throws RemoteException
	 */
	public File getFolder() throws RemoteException;

	/**
	 * Get help-file as absolute path
	 * 
	 * @return Help-file
	 * @throws RemoteException
	 */
	public File getHelpFile() throws RemoteException;

	/**
	 * Get image of component
	 * 
	 * @return Image-file
	 * @throws RemoteException
	 */
	public File getImage() throws RemoteException;

	/**
	 * List linked-files as absolute path
	 * 
	 * @return List of files
	 * @throws RemoteException
	 */
	public File[] listLinkedFiles() throws RemoteException;

	/**
	 * Get relative-path of file
	 * 
	 * @param file
	 *            Absolute file
	 * @return Relative file-path
	 * @throws RemoteException
	 */
	public String getRelLinkedFile(File file) throws RemoteException;

	/**
	 * Get parent container of component
	 * 
	 * @return Container
	 * @throws RemoteException
	 */
	public IParamContainer getContainer() throws RemoteException;

	/**
	 * Get client-implementation of interface
	 * 
	 * @return Client-implementation
	 * @throws RemoteException
	 */
	public IComponent getClientImpl() throws RemoteException;
}
