/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure;

import java.rmi.RemoteException;

/**
 * Interface of formula
 * 
 * @author Werner Koppelsttter
 */
public interface IParamFormula extends IParamField, IFunction {

	/**
	 * Get type of formula
	 * 
	 * @return Type
	 * 
	 * @throws RemoteException
	 */
	public FormulaType getFormulaType() throws RemoteException;

	/**
	 * Set type of formula
	 * 
	 * @param type
	 *            Type
	 * 
	 * @throws RemoteException
	 */
	public void setFormulaType(FormulaType type) throws RemoteException;

	/**
	 * Get expression of formula
	 * 
	 * @return expression Expression string
	 * @throws RemoteException
	 */
	public String getExpression() throws RemoteException;

	/**
	 * Set expression of formula
	 * 
	 * @param exp
	 *            Expression string
	 * @throws RemoteException
	 */
	public void setExpression(String exp) throws RemoteException;

	@Override
	public IParamFormula getClientImpl() throws RemoteException;
}
