/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.converter;

import at.lcm.bu21.general.utils.XMLNode;

/**
 * Convert to V_0_10.
 * 
 * - Modify number of combobox index
 * 
 * @author Werner Koppelsttter
 */
class Converter_10 {

	/**
	 * Convert the given node
	 * 
	 * @param node
	 *            Data to convert
	 * @return Changed data node
	 */
	static XMLNode convert(XMLNode node) {
		int length;
		// Convert Parameter
		length = Converter_10.findLength(node);
		Converter_10.updateComboBox(node, length);

		return node;
	}

	/**
	 * Get the dataset length of the project
	 * 
	 * @param node
	 *            Node to update
	 * @return Length of dataset
	 */
	private static int findLength(XMLNode node) {
		int length = 1;

		for (XMLNode n : node.getNodes()) {
			if (n.getName().compareTo("Length") == 0) {
				length = Integer.parseInt(n.getText());
			}
		}
		return length;
	}

	/**
	 * Update length of index in combobox
	 * 
	 * @param node
	 *            Node to update
	 * @param length
	 *            Length of dataset
	 */
	private static void updateComboBox(XMLNode node, int length) {
		String index;
		XMLNode item;

		if (node.getName().compareTo("ParamComboBox") == 0) {
			for (XMLNode n : node.getNodes()) {
				if (n.getName().compareTo("ComboIndex") == 0) {
					index = n.getText();
					n.clearNodes();
					for (int i = 0; i < length; i++) {
						item = new XMLNode("item");
						item.setText(index);
						n.addNode(item);
					}
				}
			}

		}

		// next Node
		for (XMLNode n : node.getNodes()) {
			Converter_10.updateComboBox(n, length);
		}

	}

}
