/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.converter;

import java.math.BigInteger;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

import at.lcm.bu21.general.utils.XMLNode;

/**
 * Convert to V_0_15.
 * 
 * - Add files-directories <br>
 * - Add DocFiles
 * 
 * @author Werner Koppelsttter
 */
public class Converter_15 {

	/**
	 * Convert the given node
	 * 
	 * @param node
	 *            Data to convert
	 * @return Changed data node
	 */
	static XMLNode convert(XMLNode node) {
		int length;

		// Convert Parameter
		length = Converter_15.findLength(node);
		Converter_15.addFilesDirs(node, length);
		Converter_15.addDocFiles(node, length);

		return node;
	}

	/**
	 * Get the dataset length of the project
	 * 
	 * @param node
	 *            Node to update
	 * @return Length of dataset
	 */
	private static int findLength(XMLNode node) {
		int length = 1;

		for (XMLNode n : node.getNodes()) {
			if (n.getName().compareTo("Length") == 0) {
				length = Integer.parseInt(n.getText());
			}
		}
		return length;
	}

	/**
	 * Add files-directories entry to Project
	 * 
	 * @param node
	 *            Node to update
	 * @param length
	 *            Length of dataset
	 */
	private static void addFilesDirs(XMLNode node, int length) {
		XMLNode items, item;
		MessageDigest md;

		if (node.getName().compareTo("Project") == 0) {
			items = new XMLNode("FilesDir");
			node.addNode(node.getNodeSize() - 1, items);
			try {
				md = MessageDigest.getInstance("MD5");
				for (int i = 0; i < length; i++) {
					item = new XMLNode("item");
					item.setText(new BigInteger(1, md.digest(Integer
							.toString(i).getBytes())).toString(16));
					items.addNode(item);
				}
			} catch (NoSuchAlgorithmException e) {
			}
		}

		// next Node
		for (XMLNode n : node.getNodes()) {
			Converter_15.addFilesDirs(n, length);
		}
	}

	/**
	 * Add files-directories entry to Project
	 * 
	 * @param node
	 *            Node to update
	 * @param length
	 *            Length of dataset
	 */
	private static void addDocFiles(XMLNode node, int length) {
		XMLNode items;

		if (node.getName().compareTo("Parameter") == 0) {
			items = new XMLNode("DocFiles");
			node.addNode(items);
			for (int i = 0; i < length; i++) {
				items.addNode(new XMLNode("item"));
			}
		}

		// next Node
		for (XMLNode n : node.getNodes()) {
			Converter_15.addDocFiles(n, length);
		}
	}

}
