/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.converter;

import java.io.File;
import java.util.LinkedList;

import at.lcm.bu21.general.utils.XMLNode;
import at.lcm.bu21.magopt.structure.ParamMatlabFunction;
import at.lcm.bu21.magopt.structure.Project;

/**
 * Convert to V_0_9.
 * 
 * - Add path to Functions
 * 
 * @author Werner Koppelsttter
 */
class Converter_9 {

	/**
	 * Convert the given node
	 * 
	 * @param node
	 *            Data to convert
	 * @param path
	 *            Directory of project
	 * @return Changed data node
	 */
	static XMLNode convert(XMLNode node, File path) {

		// Convert Parameter
		Converter_9.addFunctionPath(node, path);

		return node;
	}

	/**
	 * Add path to functions
	 * 
	 * @param node
	 *            Node to update
	 * @param path
	 *            Directory of project
	 */
	private static void addFunctionPath(XMLNode node, File path) {
		XMLNode pathNode, locNode;
		String className, classPath = null;
		String[] function;
		int classLocation = 0;

		if ((node.getName().compareTo("ParamMatlabFunction") == 0)
				|| (node.getName().compareTo("ParamJavaFunction") == 0)) {
			className = node.getNode(1).getText();
			pathNode = new XMLNode("ClassPath");
			node.addNode(pathNode);
			locNode = new XMLNode("ClassLocation");
			node.addNode(locNode);

			if (node.getName().compareTo("ParamMatlabFunction") == 0) {
				function = Converter_9.findMatlabFunction(null, className);
				if ((function != null) && (function.length == 2)) {
					classLocation = 2;
					classPath = function[0];
					className = function[1];
				}
				if (function == null) {
					function = Converter_9.findMatlabFunction(path, className);
					if ((function != null) && (function.length == 2)) {
						classLocation = 1;
						classPath = function[0];
						className = function[1];
					}
				}
			}

			node.getNode(1).setText(className);
			if (classPath != null) {
				pathNode.setText(classPath);
			}
			locNode.setText(Integer.toString(classLocation));
		}

		// next Node
		for (XMLNode n : node.getNodes()) {
			Converter_9.addFunctionPath(n, path);
		}
	}

	/**
	 * Search matlab-file of function in given path
	 * 
	 * @param path
	 *            Search path
	 * @param name
	 *            Name of function
	 * @return Array with class-path and class-name
	 */
	protected static String[] findMatlabFunction(File path, String name) {
		LinkedList<File> files = new LinkedList<File>();
		String[] function;
		int i = 0;

		if (path == null) {
			path = new File(Project.getLibraryPath());
		}

		// find files
		Converter_9.listFiles(path, name + ".m", files);

		// remove packages
		while (i < files.size()) {
			function = Converter_9.separate(path, files.get(i));
			if (function[1].compareToIgnoreCase(name) == 0) {
				i++;
			} else {
				files.remove(i);
			}
		}

		// get function
		if (files.size() == 0) {
			function = null;
		} else if (files.size() == 1) {
			function = Converter_9.separate(path, files.getFirst());
		} else {
			function = new String[0];
		}

		return function;
	}

	/**
	 * Separate class-path and class-name from file-path
	 * 
	 * @param path
	 *            Location of class
	 * @param file
	 *            Class-file
	 * @return Array with class-path and class-name
	 */
	private static String[] separate(File path, File file) {
		return ParamMatlabFunction.separatePathName(file.getPath().substring(
				path.getPath().length() + 1));
	}

	/**
	 * List all files with given name
	 * 
	 * @param path
	 *            Directory to search
	 * @param name
	 *            Name of searched files
	 * @param files
	 *            List of match files
	 */
	protected static void listFiles(File path, String name,
			LinkedList<File> files) {
		File[] list = path.listFiles();

		for (File f : list) {
			if (f.isDirectory()) {
				Converter_9.listFiles(f, name, files);
			} else {
				if (f.getName().toLowerCase().compareToIgnoreCase(name) == 0) {

					files.add(f);
				}
			}
		}

	}

}
