/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.rmi;

import java.rmi.RemoteException;
import java.util.Map;

import magopt.structure.database.DBItem;
import magopt.structure.database.MaterialConnection;
import at.lcm.bu21.magopt.structure.IDepend;
import at.lcm.bu21.magopt.structure.IParamMaterial;
import at.lcm.bu21.magopt.structure.ParamMaterial;
import at.lcm.bu21.magopt.structure.client.CParamMaterial;

/**
 * RMI adapter for material
 * 
 * @author Werner Koppelsttter
 */
public class RParamMaterial extends RParamContainer implements IParamMaterial {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** Material class */
	private ParamMaterial param;

	/**
	 * Create rmi adapter for material
	 * 
	 * @param param
	 *            Material
	 * @throws RemoteException
	 */
	public RParamMaterial(ParamMaterial param) throws RemoteException {
		super(param);
		this.param = param;
	}

	@Override
	public boolean getUpdateRequired() {
		return this.param.getUpdateRequired();
	}

	@Override
	public boolean getUpdateRequired(int index) {
		return this.param.getUpdateRequired(index);
	}

	@Override
	public void setUpdateRequired(boolean update) {
		this.param.setUpdateRequired(update);
	}

	@Override
	public void setUpdateRequired(int index, boolean update) {
		this.param.setUpdateRequired(index, update);
	}

	@Override
	public IDepend getDepend() throws RemoteException {
		return this.param.getDepend().getRMIImpl();
	}

	@Override
	public String getMaterialClassName() {
		return this.param.getMaterialClassName();
	}

	@Override
	public String getMaterialName() {
		return this.param.getMaterialName();
	}

	@Override
	public String getDatasetName() {
		return this.param.getDatasetName();
	}

	@Override
	public long getDatasetID() {
		return this.param.getDatasetID();
	}

	@Override
	public void setDatasetID(DBItem dataset, MaterialConnection conn) {
		this.param.setDatasetID(dataset, conn);
	}

	@Override
	public void setDatasetID(long datasetID, MaterialConnection conn) {
		this.param.setDatasetID(datasetID, conn);
	}

	@Override
	public void reset() {
		this.param.reset();
	}

	@Override
	public int update(Map<String, Object> args) throws Exception {
		return this.param.update(args);
	}

	@Override
	public void refreshDepend(boolean dirty, boolean load) {
		this.param.refreshDepend(dirty, load);
	}

	@Override
	public void refreshDependency() {
		this.param.refreshDependency();
	}

	@Override
	public CParamMaterial getClientImpl() {
		return new CParamMaterial(this);
	}
}
