/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui;

import java.io.File;

import javax.swing.JFileChooser;
import javax.swing.JOptionPane;

import at.lcm.bu21.magopt.structure.ParamContainer;
import at.lcm.bu21.magopt.structure.ParamDirectory;
import at.lcm.bu21.magopt.structure.ParamField;
import at.lcm.bu21.magopt.structure.ParamFile;
import at.lcm.bu21.magopt.structure.ParamFormula;
import at.lcm.bu21.magopt.structure.ParamJavaFunction;
import at.lcm.bu21.magopt.structure.ParamMatlabFunction;
import at.lcm.bu21.magopt.structure.ParamPythonFunction;
import at.lcm.bu21.magopt.structure.Parameter;
import at.lcm.bu21.magopt.structure.Project;
import magopt.gui.MagOptGui.ParamType;
import magopt.gui.helpers.JLibraryChooser;
import magopt.gui.helpers.JProgressDialog;
import magopt.gui.helpers.JProjectChooser;

/**
 * Adds or Removes a Config in a non-EDT Thread.
 * 
 * @author Aigner Markus
 * 
 */
public class InsertThread extends BaseThread {
	private Parameter mParameter;
	private ParamType mType;
	private ParamContainer mParent;
	private File mFile;

	public InsertThread(MagOptGui gui, ParamType type) {
		super(gui);
		this.mType = type;

		try {
			// TODO RMI
			Parameter selected = (Parameter) this.mGui.mProjectTree
					.getSelectedParameter();
			if (selected instanceof ParamContainer) {
				this.mParent = (ParamContainer) selected;
			} else {
				this.mParent = selected.getParent();
			}

			String newName = null;
			if (type != ParamType.TEMPLATE) {
				newName = JOptionPane.showInputDialog("Name:", "Default");
				if ((newName == null) || newName.isEmpty()) {
					this.cancel(true);
					return;
				}
			}

			switch (type) {
			case CONTAINER:
				this.mParameter = new ParamContainer(newName);
				break;
			case FUNCTION:
				JLibraryChooser chooser = new JLibraryChooser();
				if (chooser.showOpenDialog(
						this.mGui) == JFileChooser.APPROVE_OPTION) {
					if (chooser.getSelectedType()
							.equals(JLibraryChooser.MATLAB)) {
						this.mParameter = new ParamMatlabFunction(newName);
					} else if (chooser.getSelectedType()
							.equals(JLibraryChooser.JAVA_JAR)) {
						this.mParameter = new ParamJavaFunction(newName);
					} else if (chooser.getSelectedType()
							.equals(JLibraryChooser.JAVA_CLASS)) {
						this.mParameter = new ParamJavaFunction(newName);
					} else if (chooser.getSelectedType()
							.equals(JLibraryChooser.PYTHON)) {
						this.mParameter = new ParamPythonFunction(newName);
					} else {
					}
				}
				break;
			case FILE:
				this.mParameter = new ParamFile(newName);
				break;
			case FORMULA:
				this.mParameter = new ParamFormula(newName);
				break;
			case DIRECTORY:
				this.mParameter = new ParamDirectory(newName);
				break;
			case FIELD:
				this.mParameter = new ParamField(newName);
				break;
			case TEMPLATE:
				JProjectChooser pc = new JProjectChooser(
						JProjectChooser.TEMPLATE_ONLY,
						new File(Project.getLibraryPath()));
				if (pc.showOpenDialog(
						this.mGui) == JFileChooser.APPROVE_OPTION) {
					this.mFile = pc.getSelectedFile();
				} else {
					this.cancel(true);
					return;
				}
				break;
			default:
				System.err
						.println("insertNewComponent: Invalid Parameter Type");
				this.cancel(true);
				return;
			}
			this.mPD = new JProgressDialog(this.mGui, "Insert",
					"Inserting ...");

		} catch (Exception myEx) {
			JOptionPane.showMessageDialog(this.mGui, myEx.getMessage(),
					"Insert New Component", JOptionPane.ERROR_MESSAGE);
			this.cancel(true);
		}
	}

	@Override
	protected Void doInBackground() throws Exception {
		if (this.mType == ParamType.TEMPLATE) {
			Parameter[] content = Project.load(this.mFile)
					.convertToParamContainer().getParam();
			for (Parameter param : content) {
				this.mParent.addParam(param);
			}
		} else {
			this.mParent.addParam(this.mParameter);
		}
		return null;
	}

	@Override
	protected void done() {
		if (this.isCancelled() == true) {
			return;
		}
		this.mGui.updateTreeComponent();
		this.mGui.updateEventComponent();
		this.mGui.updateBars();
		this.mPD.setVisible(false);
	}
}
