/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui.view;

import java.awt.BorderLayout;
import java.awt.Desktop;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.io.File;
import java.io.IOException;
import java.rmi.RemoteException;

import javax.swing.JEditorPane;
import javax.swing.JPanel;

import at.lcm.bu21.general.utils.FileUtils;
import at.lcm.bu21.magopt.structure.IParamFunction;
import at.lcm.bu21.magopt.structure.IParamJavaFunction;
import at.lcm.bu21.magopt.structure.IParameter;

/**
 * Display html help
 * 
 * @author Werner Koppelsttter
 */
public class HelpView extends ParamBaseScroll {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** ParamFunction to display */
	private IParamFunction func = null;

	/** Pane to display html */
	protected JEditorPane browser;

	/** Main panel */
	private JPanel mainPanel;

	/**
	 * Create and initalize view
	 */
	public HelpView() {

		this.mainPanel = new JPanel();
		this.add(this.mainPanel);
		this.mainPanel.setOpaque(true);
		this.mainPanel.setVisible(false);
		this.mainPanel.setLayout(new BorderLayout());

		this.browser = new JEditorPane();
		this.browser.setEditable(false);
		this.mainPanel.add(this.browser);

		// open in browser
		this.browser.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseClicked(MouseEvent event) {
				File help;
				if (event.getClickCount() == 2) {
					help = HelpView.this.getHelpFile();
					if ((help != null) && (Desktop.isDesktopSupported())) {
						try {
							Desktop.getDesktop().browse(help.toURI());
						} catch (IOException e) {
							try {
								HelpView.this.func.info("Unable to open: " + help.getPath());
							} catch (RemoteException e1) {
								e1.printStackTrace();
							}
						}
					}

				}
			}
		});

	}

	@Override
	protected void update() {
		File file;

		file = this.getHelpFile();
		if (file != null) {
			try {
				this.browser.setPage(file.toURI().toURL());
			} catch (Exception e) {
				this.browser.setText("");
			}
		} else {
			this.browser.setText("");
		}
	}

	/**
	 * Sets new ParamFunction.
	 * 
	 * @param param
	 *            ParamFunction
	 */
	public void setFunction(IParameter param) {
		if (param instanceof IParamFunction) {
			this.func = (IParamFunction) param;
		} else {
			this.func = null;
		}
		this.mainPanel.setVisible(this.func != null);
		this.update();
	}

	/**
	 * Get help-file for the function
	 * 
	 * @return Help file
	 */
	private File getHelpFile() {
		File file, help = null;
		String name;

		if (this.func != null) {
			try {
				name = this.func.getClassName().replace(".", File.separator);
				file = new File(this.func.getClassPath());
				if (this.func instanceof IParamJavaFunction) {
					file = file.getParentFile();
				}
				file = FileUtils.getFile(file.getPath(), "tex", name + "_Doc", new File(name).getName() + ".html");
				if (!file.exists()) {
					file = new File(file.getParentFile(), new File(name).getName() + ".en.html");
					if (!file.exists()) {
						file = new File(file.getParentFile(), new File(name).getName() + ".ger.html");
					}
				}
				if (file.exists()) {
					help = file;
				}
			} catch (RemoteException e) {
				e.printStackTrace();
			}
		}

		return help;
	}
}
