/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui.view.port;

import java.awt.Component;

import javax.swing.BorderFactory;
import javax.swing.DefaultCellEditor;
import javax.swing.JTable;
import javax.swing.JTextField;
import javax.swing.ListSelectionModel;
import javax.swing.event.TableModelEvent;
import javax.swing.event.TableModelListener;

import at.lcm.bu21.magopt.structure.DependDirection;
import at.lcm.bu21.magopt.structure.IDepend;
import magopt.gui.view.ParamBaseScroll;

/**
 * Display a depend object
 * 
 * @author Werner Koppelsttter
 */
public class PortView extends ParamBaseScroll {
	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** Depends object */
	private IDepend depend;

	/** Direction of depends */
	private DependDirection direction;

	/** Imports-table */
	// public for matlab gui
	public JTable table;

	/** Import-model */
	private PortModel model;

	/**
	 * Create and initialize view
	 */
	public PortView() {
		this.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));

		// imports
		this.table = new JTable();
		this.model = new PortModel();
		this.table.setModel(this.model);
		this.table.getTableHeader().setReorderingAllowed(false);
		this.table.setColumnSelectionAllowed(true);
		this.table.setRowSelectionAllowed(true);
		this.table.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
		this.table.setDefaultRenderer(Object.class, new PortRenderer());
		// Select test by enter the editor
		this.table.setDefaultEditor(Object.class, new DefaultCellEditor(new JTextField()) {

			/** Serialization version number */
			private static final long serialVersionUID = 1L;

			@Override
			public Component getTableCellEditorComponent(JTable table, Object value, boolean isSelected, int row,
					int column) {
				Component c;
				c = super.getTableCellEditorComponent(table, value, isSelected, row, column);
				((JTextField) c).selectAll();
				return c;
			}
		});
		this.table.getColumnModel().getColumn(PortColumn.HANDLE.getValue()).setMaxWidth(30);
		this.model.addTableModelListener(new TableModelListener() {
			@Override
			public void tableChanged(TableModelEvent e) {
				PortView.this.fireParamChanged();
			}
		});
		this.add(this.table);

	}

	/**
	 * Sets new Depend object.
	 * 
	 * @param depend
	 *            Depend object
	 * @param direction
	 *            Direction of depend
	 */
	public void setDepend(IDepend depend, DependDirection direction) {
		if (this.table.isEditing()) {
			this.table.getCellEditor().cancelCellEditing();
		}
		this.depend = depend;
		this.direction = direction;
		this.update();
	}

	@Override
	protected void update() {
		this.model.setDepend(this.depend, this.direction);
	}

}
