/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui.web;

import java.awt.Desktop;
import java.net.URL;

import org.cef.browser.CefBrowser;
import org.cef.browser.CefFrame;
import org.cef.callback.CefContextMenuParams;
import org.cef.callback.CefMenuModel;
import org.cef.callback.CefMenuModel.MenuId;
import org.cef.handler.CefContextMenuHandler;

/**
 * Context menu for WebPanel
 *
 * @author Werner Koppelsttter
 */
public class ContextMenuHandler implements CefContextMenuHandler {

	public final static int EVENTFLAG_OPEN_EXTERN = 1 << 12;

	@Override
	public void onBeforeContextMenu(CefBrowser browser, CefFrame frame, CefContextMenuParams params,
			CefMenuModel model) {

//		model.clear();
		model.removeAt(0); // back
		model.removeAt(0); // foward
		model.removeAt(0); // seperator
		model.addSeparator();

		model.addItem(MenuId.MENU_ID_RELOAD, "Refresh");
		model.setEnabled(MenuId.MENU_ID_RELOAD, true);

		model.addSeparator();

		model.addItem(ContextMenuHandler.EVENTFLAG_OPEN_EXTERN, "Open extern");
		model.setEnabled(ContextMenuHandler.EVENTFLAG_OPEN_EXTERN, Desktop.isDesktopSupported());

	}

	@Override
	public boolean onContextMenuCommand(CefBrowser browser, CefFrame frame, CefContextMenuParams params, int commandId,
			int eventFlags) {

		switch (commandId) {
		case MenuId.MENU_ID_RELOAD:
			browser.reload();
			return true;
		case EVENTFLAG_OPEN_EXTERN:
			if (browser.getURL() != null) {
				try {
					Desktop.getDesktop().browse(new URL(browser.getURL()).toURI());
				} catch (Exception e) {
					System.err.println(e.getMessage());
					e.printStackTrace();
				}
				return true;
			}
			return false;
		default:
			return false;
		}
	}

	@Override
	public void onContextMenuDismissed(CefBrowser browser, CefFrame frame) {
	}

}
