/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.utils;

import java.util.Comparator;

/**
 * Natural string comparator sort strings with numbers and ignore case
 *
 * @author Werner Koppelsttter
 */
public class NaturalStringComparator implements Comparator<String> {

	@Override
	public int compare(String str1, String str2) {
		int cmp = 0;
		int index1 = 0, index2 = 0;
		int numIndex1, numIndex2;
		char ch1, ch2;

		// case insensitive
		str1 = str1.toUpperCase();
		str2 = str2.toUpperCase();

		// compare all characters
		while ((index1 < str1.length()) && (index2 < str2.length())
				&& (cmp == 0)) {
			ch1 = str1.charAt(index1);
			ch2 = str2.charAt(index2);
			// check numbers
			if (this.isDigit(ch1) && this.isDigit(ch2)) {
				numIndex1 = index1;
				numIndex2 = index2;

				do {
					index1++;
				} while (((index1) < str1.length())
						&& this.isDigit(str1.charAt(index1)));
				do {
					index2++;
				} while (((index2) < str2.length())
						&& this.isDigit(str2.charAt(index2)));

				cmp = Integer.parseInt(str1.substring(numIndex1, index1))
						- Integer.parseInt(str2.substring(numIndex2, index2));
			} else {
				cmp = ch1 - ch2;
			}
			index1++;
			index2++;
		}

		// different length
		if (cmp == 0) {
			cmp = str1.length() - str2.length();
		}

		return cmp;
	}

	/**
	 * Is the char a digit
	 * 
	 * @param ch
	 *            Character
	 * @return Is digit
	 */
	private boolean isDigit(char ch) {
		return ('0' <= ch) && (ch <= '9');
	}
}
