/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 247 $
 * $Date: 2020-03-19 10:13:52 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.optim.algorithm;

/**
 * Interface for generation-based optimizer
 * 
 * @author Werner Koppelsttter
 */
public interface GenerationBased {

	/**
	 * Create individuals for new generation
	 * 
	 * @throws Exception
	 */
	public void createPopulationIndividuals() throws Exception;

	/**
	 * Take results of generation
	 * 
	 * @throws Exception
	 */
	public void takePopulationResults() throws Exception;

	/**
	 * Get size of population
	 * 
	 * @return Polulation size
	 */
	public int getPopulationSize();

	/**
	 * Set size of population
	 * 
	 * @param popSize
	 *            Population size
	 */
	public void setPopulationSize(int popSize);

	/**
	 * Get size of population
	 * 
	 * @return Timeout (unit min)
	 */
	public int getGenerationTimeout();

	/**
	 * Set size of population
	 * 
	 * @param timeout
	 *            Timeout (unit min)
	 */
	public void setGenerationTimeout(int timeout);

}
