/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 247 $
 * $Date: 2020-03-19 10:13:52 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.optim.algorithm.me_nsga2;

import java.awt.Component;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.FocusAdapter;
import java.awt.event.FocusEvent;

import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JLabel;
import javax.swing.JTextField;
import javax.swing.LayoutStyle.ComponentPlacement;
import javax.swing.SwingConstants;

import at.lcm.bu21.optim.algorithm.JPanelSolver;

public class SsaME_Nsga2Panel extends JPanelSolver {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** Nsga2Real optimizer with setting values */
	private ME_Nsga2 solver;

	/** Size of archive */
	private JTextField txtArchiveSize;

	/** Crossover probability */
	private JTextField txtCrossoverProbability;

	/** Mutation probability */
	private JTextField txtMutationProbability;

	/**
	 * Create panel. Used by WindowsBuilder
	 */
	private SsaME_Nsga2Panel() {
		this.initComponents();
	}

	public SsaME_Nsga2Panel(ME_Nsga2 solver) {
		this();
		this.solver = solver;
		this.txtArchiveSize.setText(Integer.toString(this.solver.getArchiveSize()));
		this.txtCrossoverProbability.setText(Double.toString(this.solver.getCrossoverProbability()));
		this.txtMutationProbability.setText(Double.toString(this.solver.getMutationProbability()));

		this.refreshEnabled();
	}

	@Override
	public void refreshEnabled() {
		boolean en;

		en = this.enable && !this.solver.getProblem().isLocked();

		this.txtArchiveSize.setEnabled(en);
		this.txtCrossoverProbability.setEnabled(en);
		this.txtMutationProbability.setEnabled(en);
	}

	private void setArchiveSize() {
		try {
			this.solver.setArchiveSize(Integer.parseInt(this.txtArchiveSize.getText()));
		} catch (Exception e) {
		}
		this.txtArchiveSize.setText(Integer.toString(this.solver.getArchiveSize()));
	}

	private void setCrossoverProbability() {
		try {
			this.solver.setCrossoverProbability(Double.parseDouble(this.txtCrossoverProbability.getText()));
		} catch (Exception e) {
		}
		this.txtCrossoverProbability.setText(Double.toString(this.solver.getCrossoverProbability()));
	}

	private void setMutationProbability() {
		try {
			this.solver.setMutationProbability(Double.parseDouble(this.txtMutationProbability.getText()));
		} catch (Exception e) {
		}
		this.txtMutationProbability.setText(Double.toString(this.solver.getMutationProbability()));
	}

	private void initComponents() {
		JLabel labArchiveSize, labArchiveSizeUnit;
		JLabel labCrossoverProbability;
		JLabel labMutationProbability;

		labCrossoverProbability = new JLabel();
		labMutationProbability = new JLabel();
		labArchiveSize = new JLabel();
		this.txtCrossoverProbability = new JTextField();
		this.txtMutationProbability = new JTextField();
		this.txtArchiveSize = new JTextField();
		labArchiveSizeUnit = new JLabel();

		this.setPreferredSize(new Dimension(456, 300));

		labCrossoverProbability.setText("Crossover probability:");

		labMutationProbability.setText("Mutation probability:");

		labArchiveSize.setText("Archive size:");

		this.txtCrossoverProbability.setPreferredSize(new Dimension(100, 20));
		this.txtCrossoverProbability.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent evt) {
				SsaME_Nsga2Panel.this.setCrossoverProbability();
			}
		});
		this.txtCrossoverProbability.addFocusListener(new FocusAdapter() {
			@Override
			public void focusLost(FocusEvent evt) {
				SsaME_Nsga2Panel.this.setCrossoverProbability();
			}
		});

		this.txtMutationProbability.setPreferredSize(new Dimension(100, 20));
		this.txtMutationProbability.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent evt) {
				SsaME_Nsga2Panel.this.setMutationProbability();
			}
		});
		this.txtMutationProbability.addFocusListener(new FocusAdapter() {
			@Override
			public void focusLost(FocusEvent evt) {
				SsaME_Nsga2Panel.this.setMutationProbability();
			}
		});

		this.txtArchiveSize.setPreferredSize(new Dimension(100, 20));
		this.txtArchiveSize.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent evt) {
				SsaME_Nsga2Panel.this.setArchiveSize();
			}
		});
		this.txtArchiveSize.addFocusListener(new FocusAdapter() {
			@Override
			public void focusLost(FocusEvent evt) {
				SsaME_Nsga2Panel.this.setArchiveSize();
			}
		});

		labArchiveSizeUnit.setText("Individuals");

		GroupLayout layout = new GroupLayout(this);
		layout.setHorizontalGroup(layout.createParallelGroup(Alignment.LEADING)
				.addGroup(layout.createSequentialGroup().addContainerGap()
						.addGroup(layout.createParallelGroup(Alignment.LEADING).addComponent(labArchiveSize)
								.addComponent(labCrossoverProbability).addComponent(labMutationProbability))
						.addGap(18)
						.addGroup(layout.createParallelGroup(Alignment.LEADING)
								.addGroup(layout.createSequentialGroup()
										.addGroup(layout.createParallelGroup(Alignment.LEADING)
												.addGroup(layout.createSequentialGroup()
														.addComponent(this.txtArchiveSize, 0, 60, Short.MAX_VALUE)
														.addPreferredGap(ComponentPlacement.UNRELATED)
														.addComponent(labArchiveSizeUnit, GroupLayout.PREFERRED_SIZE,
																70, GroupLayout.PREFERRED_SIZE)
														.addGap(8))
												.addGroup(layout.createSequentialGroup()
														.addComponent(this.txtCrossoverProbability, 0, 60,
																Short.MAX_VALUE)
														.addGap(77)))
										.addGap(188))
								.addGroup(layout
										.createSequentialGroup().addComponent(this.txtMutationProbability,
												GroupLayout.PREFERRED_SIZE, 60, GroupLayout.PREFERRED_SIZE)
										.addContainerGap()))));
		layout.setVerticalGroup(layout.createParallelGroup(Alignment.LEADING)
				.addGroup(layout.createSequentialGroup().addContainerGap()
						.addGroup(layout.createParallelGroup(Alignment.BASELINE).addComponent(labArchiveSize)
								.addComponent(this.txtArchiveSize, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE,
										GroupLayout.PREFERRED_SIZE)
								.addComponent(labArchiveSizeUnit))
						.addPreferredGap(ComponentPlacement.UNRELATED)
						.addGroup(layout.createParallelGroup(Alignment.BASELINE).addComponent(labCrossoverProbability)
								.addComponent(this.txtCrossoverProbability, GroupLayout.PREFERRED_SIZE,
										GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
						.addPreferredGap(ComponentPlacement.UNRELATED)
						.addGroup(layout.createParallelGroup(Alignment.BASELINE).addComponent(labMutationProbability)
								.addComponent(this.txtMutationProbability, GroupLayout.PREFERRED_SIZE,
										GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
						.addContainerGap(207, Short.MAX_VALUE)));
		layout.linkSize(SwingConstants.HORIZONTAL,
				new Component[] { this.txtCrossoverProbability, this.txtMutationProbability, this.txtArchiveSize });
		this.setLayout(layout);
	}

}
