#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision$
$LastChangedDate::                           $

This file is part of SyMSpace.

Copyright (c) 2020, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""

import os
from symspace.generic_gui_qt import GUIFormThread
from symspace.generic_gui_qt import GUIMessageThread
from symspace.console.script_utils import ScriptUtils
from symspace.wrapper.symwrapper import SymProject
from symspace.utils.tree_manipulation import ModelDescription


def main(project: SymProject, parameter):

    default_path = os.path.join(project.getDirectory(), project.getName() + '.xlsx')
    prj_indices = [str(x + 1) for x in range(project.getLength())]
    form_title = 'Export params to file'
    form_elements = [('Select file', 'browse_file', default_path,
                      'Excel Files (*.xls *.xlsx)'),  # ;;CSV-files (*.csv);;Json-files (*.json)
                     ('Select Project Index', 'combobox', prj_indices),
                     ('Scalar Export Only', 'checkbox', True),
                     ('Evaluate "Used by"', 'checkbox', False),
                     ('Fail on error', 'checkbox', True)
                     ]
    form = GUIFormThread(form_title, form_elements)

    form.start()
    if form.accept:
        file_path = os.path.join(form.result['Select file'])
        index = int(form.result['Select Project Index']) - 1
        md = ModelDescription(project, index=index)
        md.fail_on_error = form.result['Fail on error']
        md.export_scalar_only = form.result['Scalar Export Only']
        md.export_eval_used_by = form.result['Evaluate "Used by"']

        if file_path.endswith('.xls') or file_path.endswith('.xlsx'):
            md.exportToExcel(file_path)
        else:
            file_ending = file_path.split('.')[-1]
            raise Exception('Filetype "{}" is not supported'.format(file_ending))

        if len(md.warning_msgs) > 0:
            msg_text = '\n'.join(md.warning_msgs)
            msg = GUIMessageThread('Warning', {'icon': 'warning', 'text': msg_text, 'buttons': 'ok'})
            msg.start()
            project.warning(msg_text)

        print('Update finished')
    else:
        print('Cancelled by user')


if __name__ == '__main__':
    """
    This script exports a ModelDescription file from the project tree

    This script needs to be executed in the SyMSpace Python Console.
    """

    ScriptUtils.runWithParams(main, locals())
