#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision$
$LastChangedDate::                           $

This file is part of SyMSpace.

Copyright (c) 2020, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
import os
import tempfile
from symspace.wrapper.symwrapper import SymProject
from symspace.generic_gui_qt import GUIFormThread, GUIMessageThread
from symspace.console.script_utils import ScriptUtils
from symspace.utils.tree_manipulation import ModelDescription
from symspace.osutils.pathutils import symspace_home


def main(project: SymProject, parameter):
    if project is None:
        '''creat a temporary project'''
        file = os.path.join(tempfile.mkdtemp(), 'Project.mop')
        project = SymProject.new('Project', 'Project from ModelDescription', file)
        open_project = True
    else:
        file = ''
        open_project = False

    default_path = os.path.join(project.getDirectory(), project.getName() + '.xlsx')
    prj_indices = [str(x + 1) for x in range(project.getLength())]
    form_title = 'Load data from file'
    form_elements = [('Select file', 'browse_file', default_path,
                      'Excel Files (*.xls *.xlsx)'),  # ;;CSV-files (*.csv);;Json-files (*.json)
                     ('Select Project Index', 'combobox', prj_indices),
                     ('Insert Components', 'checkbox', True),
                     ('Add missing Fields', 'checkbox', True),
                     ('Add missing Containers', 'checkbox', True),
                     ('Fail on error', 'checkbox', True)
                     ]
    form = GUIFormThread(form_title, form_elements)

    form.start()
    if form.accept:
        file_path = os.path.join(form.result['Select file'])
        index = int(form.result['Select Project Index']) - 1
        md = ModelDescription(project, index=index)
        md.fail_on_error = form.result['Fail on error']
        md.import_add_missing_fields = form.result['Add missing Fields']
        md.import_add_missing_containers = form.result['Add missing Containers']
        md.import_insert_components = form.result['Insert Components']

        if file_path.endswith('.xls') or file_path.endswith('.xlsx'):
            md.updateFromExcel(file_path)
        # elif file_path.endswith('.json'):
        #     md.updateFromJSON(file_path)
        # elif file_path.endswith('.csv'):
        #     md.updateFromCSV(file_path)
        else:
            file_ending = file_path.split('.')[-1]
            raise Exception('Filetype "{}" is not supported'.format(file_ending))

        if len(md.warning_msgs) > 0:
            msg_text = '\n'.join(md.warning_msgs)
            msg = GUIMessageThread('Warning', {'icon': 'warning', 'text': msg_text, 'buttons': 'ok'})
            msg.start()

        print('Update finished')

        if open_project and file != '':
            project.save()
            os.system(os.path.join(symspace_home, 'SyMSpace.exe') + ' ' + file)

    else:
        print('Cancelled by user')


if __name__ == '__main__':
    """
    This script updates the project tree from a ModelDescription compatible file

    This script needs to be executed in the SyMSpace Python Console.
    """

    ScriptUtils.runWithParams(main, locals(), needs_project=False)
