#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 9039 $
$LastChangedDate:: 2019-03-18 17:49:36 +0100#$

This file is part of SyMSpace.

Copyright (c) 2019, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""

import os
import json
from symspace.wrapper.symwrapper import SymProject


def writeJSON(prj: SymProject) -> None:
    """
    Write a json file of the project data to the project directory

    Parameters
    ----------
    prj : SymProject
        SyMSpace Project Instance

    """
    fname = prj.getFile()
    dirpath = os.path.join(prj.getDirectory(), 'JSONData')
    if not os.path.exists(dirpath):
        os.mkdir(dirpath)

    num = 1
    for fh in os.listdir(dirpath):
        if fh.startswith(fname):
            num += 1
    jstr = json.dumps(prj.getRoot().toDict(detailed=True))
    fname = fname + '_{:04}.json'.format(num)

    with open(os.path.join(dirpath, fname), 'w') as fh:
        fh.write(jstr)


if __name__ == '__main__':
    """
    This script writes a json file of the project data to the project directory.
    """
    project = locals()['__project__']
    writeJSON(project)
    print('JSON written')
