#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.5

$LastChangedRevision: 9194 $
$LastChangedDate:: 2019-06-12 18:24:37 +0200#$

This file is part of SyMSpace.
@author: mkitzberger

Copyright (c) 2017, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""

if __name__ == '__main__':
    import sys

    """
    Building a basic project with multiple project indexes from scratch and 
    plot numeric values over the project indices
    
    !!! This project assumes that an (empty) project was assigned to the variable 'CurProject' inside SyMSpace (Strg + P)
    """

    try:

        from symspace.wrapper.symplot import SymPlot2Line
        from symspace.wrapper.prettyprint import SymPrettyPrintConverter
        from symspace.wrapper.symwrapper import SymContainer, SymField, SymPythonFunction, SymProject

        CurProject = locals()['CurProject']
        print(70 * '-')
        print('Running script!!!\n')
        print('# Delete all existing parameters')
        parameter_list = CurProject.getParam()
        for parameter in parameter_list:
            parameter.removeParam()
        print('# Removing all existing indexes .....')
        for i in range(CurProject.getLength()):
            CurProject.reduce()
        print('# Creating three Containers')
        container1 = SymContainer('container1', 'This is container1')
        container2 = SymContainer('container2', 'This is container2')
        container3 = SymContainer('container3', 'This is container3')
        print('# Creating six Parameters')
        param1 = SymField('param1')
        param2 = SymField('param2')
        param3 = SymField('param3')
        param4 = SymField('param4')
        param5 = SymField('param5')
        param6 = SymField('param6')
        print('# Adding Parameters to Containers')
        container1.addParam(param1)  # at the end
        container1.addParam(param2)  # at the end
        container2.addParam(param3)  # at the end
        container2.addParam(param4)  # at the end
        container3.addParam(param5)  # at the end
        container3.addParam(param6)  # at the end
        print("# Adding Containers to Project (assumes Project handle assigned to variable 'CurProject' with Strg + P)")
        CurProject.addParam(container1)  # at the end
        CurProject.addParam(container2)  # at the end
        CurProject.addParam(container3)  # at the end
        print('# Adding a Python function to the Project')
        func = SymPythonFunction('PythonFunction', 'This is a test function with certain imports an exports')
        # Set name of python module (= filename without .py extension, module must be available in current project directory)
        func.setModuleName('fnc_pytemplate')
        # Set name of class in module
        func.setClassName('FncPyTemplate')
        CurProject.addParam(func)
        print('# Add an export variable to the function which is also a container')
        c = SymField('c')
        signal = SymField('signal')
        CurProject['PythonFunction'].addParam(c)
        CurProject['PythonFunction'].addParam(signal)
        CurProject['PythonFunction'].setImportAssignments({'a': 'param1', 'b': 'param2'})
        CurProject['PythonFunction'].setExportAssignments({'c': 'c', 'signal': 'signal'})
        print('# Adding three indices to the project')
        for i in range(3):
            CurProject.duplicate()
        print('# Setting project on index 1')
        CurProject.setIndex(1)
        print('# Modify Parameter of index 1')
        CurProject['container1.param1'].setData(1)
        CurProject['container1.param2'].setData(2)
        CurProject['container2.param3'].setData(3)
        CurProject['container2.param4'].setData(4)
        CurProject['container3.param5'].setData(5)
        CurProject['container3.param6'].setData(6)
        print('# Setting project on index 2')
        CurProject.setIndex(2)
        print('# Modify Parameter of index 2')
        CurProject['container1.param1'].setData(2)
        CurProject['container1.param2'].setData(2)
        CurProject['container2.param3'].setData(2)
        CurProject['container2.param4'].setData(2)
        CurProject['container3.param5'].setData(2)
        CurProject['container3.param6'].setData(2)
        print('# Setting project on index 3')
        CurProject.setIndex(3)
        print('# Modify Parameter of index 3')
        CurProject['container1.param1'].setData(3)
        CurProject['container1.param2'].setData(3)
        CurProject['container2.param3'].setData(3)
        CurProject['container2.param4'].setData(3)
        CurProject['container3.param5'].setData(3)
        CurProject['container3.param6'].setData(3)
        print('# Setting project on index 4')
        CurProject.setIndex(4)
        print('# Modify Parameter of index 4')
        CurProject['container1.param1'].setData(3)
        CurProject['container1.param2'].setData(3)
        CurProject['container2.param3'].setData(3)
        CurProject['container2.param4'].setData(3)
        CurProject['container3.param5'].setData(3)
        CurProject['container3.param6'].setData(3)
        print('# Regenerating all indices of Project')
        for index in range(CurProject.getLength()):
            CurProject.setIndex(index)
            status = CurProject.regenerate(RunSim=False, RemoteCompute=False, Optimize=False)
            CurProject.refresh()
            CurProject.refreshFlags()
            print('# Regenerating index: {}, status: {}'.format(index + 1, status))
        print('# Plot the signal returned from python function')
        handle = SymPlot2Line()
        handle.addSignal('signal', CurProject['PythonFunction.signal'].getData())
        handle.setTitle('signal')
        handle.show()
        print('# Plot parameter over indices as line')
        handle = SymProject.plotParameter(CurProject['container1.param1'])
        handle.show()
        print('# Plot parameter over indices as bars')
        handle = SymProject.plotParameter(CurProject['container1.param1'], mode='bar')
        handle.show()
        print('# Plot one parameter over another parameter')
        handle = SymProject.plotParameter(CurProject['container1.param1'], CurProject['container1.param2'])
        handle.show()
        print('# Plot multiple parameter over one parameter')
        handle = SymProject.plotParameter(CurProject['container1.param1'],
                                          [CurProject['container1.param1'], CurProject['container3.param6']])
        handle.show()
        print('# Plot histogramm of a parameter over indices')
        handle = SymProject.plotParamHistogramm(CurProject['container1.param1'])
        handle.show()
        print('# Getting import Parameters of a Function')
        func = CurProject['PythonFunction']
        importParameter = [dependItem.getHandle() for dependItem in func.getImports()]
        # create prettyprint version for jep console
        importParameter = SymPrettyPrintConverter.ugly2pretty(importParameter)
        print(repr(importParameter))
        print('# Getting import Parameter Names')
        names = [dependItem.getParamName() for dependItem in func.getImports()]
        # create prettyprint version for jep console
        names = SymPrettyPrintConverter.ugly2pretty(names)
        print(repr(names))
        print('# Getting export Parameters of a Function')
        func = CurProject['PythonFunction']
        exportParameter = [dependItem.getHandle() for dependItem in func.getExports()]
        # create prettyprint version for jep console
        exportParameter = SymPrettyPrintConverter.ugly2pretty(exportParameter)
        print(repr(exportParameter))
        print('# Getting export Parameter Names')
        names = [dependItem.getParamName() for dependItem in func.getExports()]
        # create prettyprint version for jep console
        names = SymPrettyPrintConverter.ugly2pretty(names)
        print(repr(names))
        print('# Saving new project in MagOpt base directory')
        CurProject.saveAs(strFile='NewProject.mop', override=True)
        print('')
        print(70 * '-')
        print('Script finished!!!')

    except Exception as e:
        exc_type, exc_value, exc_traceback = sys.exc_info()
        print('\n{} in Script on line {}:'.format(exc_type.__name__, exc_traceback.tb_lineno))
        print(exc_value)
