# !/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 9896 $
$LastChangedDate:: 2020-06-30 08:41:38 +0200#$

This file is part of SyMSpace.

Copyright (c) 2018, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
import os
import unittest
from symspace.testing.moptestrunner import SymProjectTestsuite
from symspace.osutils.processutils import getInterpreter
from symspace.osutils.pathutils import symspace_home
try:
    # noinspection PyUnresolvedReferences
    from unittest.runner import _WritelnDecorator
except:
    _WritelnDecorator = None


class TestSymProjectTestsuite(unittest.TestCase):

    def test_discover(self):
        path = os.path.join(symspace_home, 'System', 'Python', 'tests')
        expected_file = os.path.join(path, 'test_symspace', 'test_testing', 'test_symProjectTestsuite.mop')
        found_test_files = SymProjectTestsuite.discover(path)

        if expected_file not in found_test_files:
            self.fail('Expected test ({}) not found!'.format(expected_file))

    @unittest.skipIf(getInterpreter() == 'python', 'needs jep interpreter to run')
    def test_run(self):
        path = os.path.join(symspace_home, 'System', 'Python', 'tests', 'test_symspace')
        suite = SymProjectTestsuite(path)
        if _WritelnDecorator is not None:
            '''suppress output of internal unittests'''
            stream = _WritelnDecorator(open('nul', 'w'))
            suite.runner.stream = stream
        else:
            stream = None

        result = suite.run()

        if stream is not None:
            stream.close()

        expected_failures = ('test_symProjectMissingAssertComment, __generate__',
                             'test_symProjectMissingAssertParameter, __generate__'
                             )

        for elem in result.failures:
            test_method = elem[0]._testMethodName.split('\\')[-1]
            self.assertIn(test_method, expected_failures)

        self.assertEqual(str(result),
                         '<unittest.runner.TextTestResult run={:d} errors=0 failures={:d}>'
                         .format(result.testsRun, len(expected_failures)))


if __name__ == '__main__':
    from lcm.utils.testing import runUnittest

    runUnittest(getInterpreter())
