/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9720 $
 * $Date: 2020-03-19 15:59:49 +0100 (Thu, 19 Mar 2020) $
 */
package jobmanager.server.gui;

import java.io.File;

import javax.swing.JTable;
import javax.swing.event.TableModelEvent;
import javax.swing.event.TableModelListener;
import javax.swing.table.AbstractTableModel;

import jobmanager.server.Job;
import jobmanager.server.JobAdapter;

/**
 * Table model for job-list
 * 
 * @author Werner Koppelsttter
 */
public class JobListModel extends AbstractTableModel {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** List of jobs */
	private Job[] jobs = null;

	/**
	 * Set jobs to display
	 * 
	 * @param jobs
	 *            List of jobs
	 */
	public void setJobs(Job[] jobs) {
		this.jobs = jobs;

		// refresh table of model
		for (TableModelListener listener : this
				.getListeners(TableModelListener.class)) {
			if ((listener instanceof JTable)
					&& this.equals(((JTable) listener).getModel())) {
				listener.tableChanged(new TableModelEvent(this));
			}
		}
	}

	@Override
	public int getColumnCount() {
		return JobListColumn.values().length;
	}

	@Override
	public int getRowCount() {
		int len = 0;

		if (this.jobs != null) {
			len = this.jobs.length;
		}

		return len;
	}

	@Override
	public Object getValueAt(int row, int column) {
		Object obj = null;
		Job job;
		JobAdapter adapter;

		if (this.jobs != null) {
			job = this.jobs[row];
			adapter = job.getAdapter();
			if (column == JobListColumn.PROJECT.getValue()) {
				obj = new File(job.getProject()).getName();
			} else if (column == JobListColumn.DATASET.getValue()) {
				obj = job.getDataset();
			} else if (column == JobListColumn.PARAMETER.getValue()) {
				obj = job.getParameter();
			} else if (column == JobListColumn.NAME.getValue()) {
				obj = job.getName();
			} else if (column == JobListColumn.STATUS.getValue()) {
				obj = job.getStatusString();
			} else if (column == JobListColumn.ID.getValue()) {
				if (adapter != null) {
					obj = adapter.getID();
				}
			} else if (column == JobListColumn.RUNTIME.getValue()) {
				obj = job.getRuntime();
			} else if (column == JobListColumn.HOST.getValue()) {
				obj = job.getHost();
			} else {
				obj = job;
			}
		}

		return obj;
	}

	@Override
	public String getColumnName(int column) {
		for (JobListColumn e : JobListColumn.values()) {
			if (e.getValue() == column) {
				return e.getName();
			}
		}
		return null;
	}

	@Override
	public boolean isCellEditable(int row, int column) {
		return false;
	}

	@Override
	public Class<?> getColumnClass(int column) {
		return String.class;
	}
}
