/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9720 $
 * $Date: 2020-03-19 15:59:49 +0100 (Thu, 19 Mar 2020) $
 */
package viewer3d;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.LinkedList;

/**
 * Convert material-file (*.mtl)
 * 
 * @author Werner Koppelsttter
 */
public class MaterialConverter {

	/**
	 * Convert material-file
	 * 
	 * @param file
	 *            File to convert
	 * @throws IOException
	 */
	public static void convertMaterial(String file) throws IOException {
		convertMaterial(new File(file));

	}

	/**
	 * Convert material-file
	 * 
	 * @param file
	 *            File to convert
	 * @throws FileNotFoundException
	 * @throws IOException
	 */
	public static void convertMaterial(File file) throws IOException {
		boolean dirty = false, found = true;
		String str;
		LinkedList<String> content = new LinkedList<String>();
		BufferedReader in;
		BufferedWriter out;
		int index = 0, pointer = 0;

		// Select file
		if (file.getName().endsWith(".obj")) {
			String path = file.getAbsolutePath();
			file = new File(path.substring(0, path.length() - 4) + ".mtl");
		}

		// convert File
		if (file.exists()) {
			// read File and convert
			in = new BufferedReader(new FileReader(file));
			while ((str = in.readLine()) != null) {
				// search for illum tag in each material
				if (str.startsWith("newmtl")) {
					if (!found) {
						dirty = true;
						content.add(pointer + 1, "illum 1");
						index++;
					}
					pointer = index;
					found = false;
				} else if (str.startsWith("illum")) {
					found = true;
				}
				content.add(str);
				index++;
			}
			if (!found) {
				dirty = true;
				content.add(pointer + 1, "illum 1");
			}
			in.close();

			// write File
			if (dirty) {
				out = new BufferedWriter(new FileWriter(file));
				while (content.size() > 0) {
					out.write(content.remove());
					out.newLine();
				}
				out.close();
			}
		}
	}

}
